package com.gonexwind.todo.data

import androidx.room.*
import com.gonexwind.todo.data.model.ToDoTask
import kotlinx.coroutines.flow.Flow

@Dao
interface ToDoDao {

    @Query("SELECT * FROM todo_table ORDER BY id")
    fun getAllTasks(): Flow<List<ToDoTask>>

    @Query("SELECT * FROM todo_table WHERE id=:taskId")
    fun getSelectedTask(taskId: Int): Flow<ToDoTask>

    @Insert(onConflict = OnConflictStrategy.IGNORE)
    suspend fun addTask(toDoTask: ToDoTask)

    @Update
    suspend fun updateTask(toDoTask: ToDoTask)

    @Delete
    suspend fun deleteTask(toDoTask: ToDoTask)

    @Query("DELETE FROM todo_table")
    suspend fun deleteAllTasks()

    @Query("SELECT * FROM todo_table WHERE title LIKE :query OR description LIKE :query")
    fun searchTask(query: String): Flow<List<ToDoTask>>

    @Query(
        """
        SELECT * FROM todo_table ORDER BY
            CASE
                WHEN priority LIKE 'L%' THEN 1
                WHEN priority LIKE 'M%' THEN 2
                WHEN priority LIKE 'H%' THEN 3
            END
        """
    )
    fun sortByLowPriority(): Flow<List<ToDoTask>>

    @Query(
        """
        SELECT * FROM todo_table ORDER BY
            CASE
                WHEN priority LIKE 'H%' THEN 1
                WHEN priority LIKE 'M%' THEN 2
                WHEN priority LIKE 'L%' THEN 3
            END
        """
    )
    fun sortByHighPriority(): Flow<List<ToDoTask>>

}